==> com.liferay.site.navigation.admin.web-3.0.24.jar: META-INF/resources/site_navigation_menu_editor/contexts/SelectedMenuItemIdContext.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.24/site_navigation_menu_editor/contexts/SelectedMenuItemIdContext", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SelectedMenuItemIdProvider = exports.useSelectedMenuItemId = exports.useSetSelectedMenuItemId = void 0;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SelectedMenuItemIdContext = _react["default"].createContext({});

    var SetSelectedMenuItemIdContext = _react["default"].createContext(function () {});

    var useSetSelectedMenuItemId = function useSetSelectedMenuItemId() {
      return (0, _react.useContext)(SetSelectedMenuItemIdContext);
    };

    exports.useSetSelectedMenuItemId = useSetSelectedMenuItemId;

    var useSelectedMenuItemId = function useSelectedMenuItemId() {
      return (0, _react.useContext)(SelectedMenuItemIdContext);
    };

    exports.useSelectedMenuItemId = useSelectedMenuItemId;

    var SelectedMenuItemIdProvider = function SelectedMenuItemIdProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)(null),
          _useState2 = _slicedToArray(_useState, 2),
          selectedMenuItemId = _useState2[0],
          setSelectedMenuItemId = _useState2[1];

      return _react["default"].createElement(SetSelectedMenuItemIdContext.Provider, {
        value: setSelectedMenuItemId
      }, _react["default"].createElement(SelectedMenuItemIdContext.Provider, {
        value: selectedMenuItemId
      }, children));
    };

    exports.SelectedMenuItemIdProvider = SelectedMenuItemIdProvider;
    SelectedMenuItemIdContext.propTypes = {
      setSidebarPanelId: _propTypes["default"].func
    };
    //# sourceMappingURL=SelectedMenuItemIdContext.js.map
  }
});
//# sourceMappingURL=SelectedMenuItemIdContext.js.map

==> com.liferay.site.navigation.admin.web-3.0.35.jar: META-INF/resources/site_navigation_menu_editor/contexts/SelectedMenuItemIdContext.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.35/site_navigation_menu_editor/contexts/SelectedMenuItemIdContext", ['module', 'exports', 'require', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SelectedMenuItemIdProvider = exports.useSelectedMenuItemId = exports.useSetSelectedMenuItemId = void 0;

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SelectedMenuItemIdContext = /*#__PURE__*/_react.default.createContext(null);

    var SetSelectedMenuItemIdContext = /*#__PURE__*/_react.default.createContext(function () {});

    var useSetSelectedMenuItemId = function useSetSelectedMenuItemId() {
      return (0, _react.useContext)(SetSelectedMenuItemIdContext);
    };

    exports.useSetSelectedMenuItemId = useSetSelectedMenuItemId;

    var useSelectedMenuItemId = function useSelectedMenuItemId() {
      return (0, _react.useContext)(SelectedMenuItemIdContext);
    };

    exports.useSelectedMenuItemId = useSelectedMenuItemId;

    var SelectedMenuItemIdProvider = function SelectedMenuItemIdProvider(_ref) {
      var children = _ref.children;

      var _useState = (0, _react.useState)(null),
          _useState2 = _slicedToArray(_useState, 2),
          selectedMenuItemId = _useState2[0],
          setSelectedMenuItemId = _useState2[1];

      return (/*#__PURE__*/_react.default.createElement(SetSelectedMenuItemIdContext.Provider, {
          value: setSelectedMenuItemId
        }, /*#__PURE__*/_react.default.createElement(SelectedMenuItemIdContext.Provider, {
          value: selectedMenuItemId
        }, children))
      );
    };

    exports.SelectedMenuItemIdProvider = SelectedMenuItemIdProvider;
    //# sourceMappingURL=SelectedMenuItemIdContext.js.map
  }
});
//# sourceMappingURL=SelectedMenuItemIdContext.js.map
